package com.someco.scripts;

import java.util.HashMap;
import java.util.Map;

import org.alfresco.service.cmr.repository.NodeRef;
import org.alfresco.web.scripts.WebScriptRequest;
import org.alfresco.web.scripts.WebScriptStatus;
import org.apache.log4j.Logger;

import com.someco.behavior.Rating;

/**
 * This is the controller for the rating.post web script.
 * 
 * @author jpotts
 * 
 */
public class PostRating extends org.alfresco.web.scripts.DeclarativeWebScript {

	Logger logger = Logger.getLogger(PostRating.class);
			
	private Rating ratingBean;
	
	@Override
	protected Map<String, Object> executeImpl(WebScriptRequest req, WebScriptStatus status) {
		String id =	req.getParameter("id");
		String rating = req.getParameter("rating");
		String user = req.getParameter("user");

		if (id == null || rating == null || rating.equals("0") || user == null) {
			logger.debug("ID, rating, or user not set");
			status.jsSet_code(400);			
			status.jsSet_message("Required data has not been provided");
			status.jsSet_redirect(true);
		} else {
			logger.debug("Getting current node");
			NodeRef curNode = new NodeRef("workspace://SpacesStore/" + id);	
			if (curNode == null) {
				logger.debug("Node not found");
				status.jsSet_code(404);
				status.jsSet_message("No node found for id:" + id);
				status.jsSet_redirect(true);
			} else {
				ratingBean.create(curNode, Integer.parseInt(rating), user);
				logger.debug("Back from ratingBean.create()");
			}
		
		}

		logger.debug("Setting model");
		Map<String, Object> model = new HashMap<String, Object>();
		model.put("node", id);
		model.put("rating", rating);
		model.put("user", user);
		
		return model;
	}

	public Rating getRatingBean() {
		return ratingBean;
	}

	public void setRatingBean(Rating ratingBean) {
		this.ratingBean = ratingBean;
	}

}
